"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFallback = exports.getDeclaration = exports["default"] = void 0;

/**
 * @file Parses a CSS custom property string.
 * @author Simon Finney
 */

/**
 * Gets the value between two points in a string.
 *
 * @param {string} string The string to parse.
 * @param {string} start The starting point to parse.
 * @param {string} end The end point to parse.
 *
 * @returns {string} The value between the start and end points.
 */
var getValueBetween = function getValueBetween(string, start, end) {
  return string.substring(string.indexOf(start) + 1, string.indexOf(end));
};
/**
 * Parses a CSS custom property string and returns the declaration.
 *
 * @param {string} cssCustomPropertyString The CSS custom property string to parse.
 *
 * @returns {string} The parsed CSS custom property declaration.
 */


var getDeclaration = function getDeclaration(cssCustomPropertyString) {
  return getValueBetween(cssCustomPropertyString, '(', ',');
};
/**
 * Parses a CSS custom property string and returns the fallback.
 *
 * @param {string} cssCustomPropertyString The CSS custom property string to parse.
 * @returns {string} The parsed CSS custom property fallback.
 */


exports.getDeclaration = getDeclaration;

var getFallback = function getFallback(cssCustomPropertyString) {
  return getValueBetween(cssCustomPropertyString, ' ', ')');
};
/**
 * Parses a CSS custom property string and returns an object containing the declaration and fallback.
 *
 * @param {string} cssCustomPropertyString The CSS custom property string to parse.
 * @returns {object} An object containing the parsed CSS custom property declaration and fallback.
 */


exports.getFallback = getFallback;

var _default = function _default(cssCustomPropertyString) {
  return {
    declaration: getDeclaration(cssCustomPropertyString),
    fallback: getFallback(cssCustomPropertyString)
  };
};

exports["default"] = _default;
